.. _get_involved:

Get Involved
============

.. toctree::
   :maxdepth: 1
   :hidden:

   get_involved/contributing
   get_involved/mentoring
   get_involved/meetups

sktime is a community-driven project and your help is extremely welcome.
If you get stuck, please don’t hesitate to chat with us or raise an issue.

.. panels::
    :card: + intro-card text-center

    ---

    Contributing
    ^^^^^^^^^^^^

    New to sktime? Check out the contributing guide.

    +++

    .. link-button:: contributing
            :type: ref
            :text: Contributing guide
            :classes: btn-block btn-secondary stretched-link

    ---

    Mentoring
    ^^^^^^^^^

    New to open source? Apply to our mentoring program!

    +++

    .. link-button:: mentoring
            :type: ref
            :text: Mentoring
            :classes: btn-block btn-secondary stretched-link

    ---

    Sponsoring
    ^^^^^^^^^^

    Fund sktime maintenance and development.

    +++

    .. link-button:: https://opencollective.com/sktime
            :text: Donate
            :classes: btn-block btn-secondary stretched-link

    ---

    Meet-ups
    ^^^^^^^^

    Join our discussions, tutorials, workshops and sprints!

    +++

    .. link-button:: meetups
            :type: ref
            :text: Participate
            :classes: btn-block btn-secondary stretched-link
